@@ -35,6 +35,11 @@
  */
 
 #include <ctype.h>
+#include <sys/types.h>
+#include <sys/socket.h>
+#include <netinet/in.h>
+#include <arpa/inet.h>
+
 #include <ldns/buffer.h>
 #include "types-internal.h"
 #include "util-internal.h"
@@ -47,7 +52,6 @@
  * private function used to locate a key in a dictionary
  * @param dict dicitonary to search
  * @param key key to search for
- * @param addifnotfnd if TRUE then an item will be added if the key is not found
  * @return pointer to dictionary item, caller must not free storage associated with item
  * @return NULL if additnotfnd == FALSE and key is not in dictionary
  */
@@ -342,7 +346,9 @@ getdns_dict_copy(const struct getdns_dict * srcdict,
 /*---------------------------------------- getdns_dict_item_free */
 /**
  * private function used to release storage associated with a dictionary item
- * @param item all memory in this structure and its children will be freed
+ * @param node all memory in this structure and its children will be freed
+ * @param arg is a dict who's custom memory function will be used 
+ *            to free the items
  * @return void
  */
 void
@@ -742,6 +748,8 @@ getdns_pp_dict(ldns_buffer * buf, size_t indent,
 	struct getdns_dict_item *item;
 	const char *strval;
 
+	char abuf[80];
+
 	if (dict == NULL)
 		return 0;
 
@@ -792,8 +800,23 @@ getdns_pp_dict(ldns_buffer * buf, size_t indent,
 			break;
 
 		case t_bindata:
-			if (getdns_pp_bindata(buf, indent,
-				item->data.bindata) < 0)
+			if ((strcmp(item->node.key, "address_data") == 0 ||
+			     strcmp(item->node.key, "ipv4_address") == 0 ||
+			     strcmp(item->node.key, "ipv6_address") == 0 ) &&
+			    (item->data.bindata->size == 4  ||
+			     item->data.bindata->size == 16 )) {
+
+				if (ldns_buffer_printf(buf, " <bindata for %s>",
+				    inet_ntop(( item->data.bindata->size == 4
+				              ? AF_INET : AF_INET6)
+					     , item->data.bindata->data
+					     , abuf
+					     , 40
+					     )) < 0)
+					return -1;
+	
+			} else if (getdns_pp_bindata(buf, indent,
+			    item->data.bindata) < 0)
 				return -1;
 			break;
 
